nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Cr18

Struct Cr18 

#[repr(transparent)]
pub struct Cr18(pub u32);
CSI Control Register 18

Tuple Fields

0: u32

Implementations

Source

impl Cr18

pub const fn deinterlace_en(&self) -> DeinterlaceEn

This bit is used to select the output method When input is standard BT.656 video.

pub const fn set_deinterlace_en(&mut self, val: DeinterlaceEn)

This bit is used to select the output method When input is standard BT.656 video.

pub const fn parallel24_en(&self) -> Parallel24En

Enable bit for Parallel RGB888/YUV444 24bit input

pub const fn set_parallel24_en(&mut self, val: Parallel24En)

Enable bit for Parallel RGB888/YUV444 24bit input

pub const fn baseaddr_switch_en(&self) -> bool

When this bit is enabled, CSI DMA will switch the base address according to BASEADDR_SWITCH_SEL rather than automatically by DMA completed

pub const fn set_baseaddr_switch_en(&mut self, val: bool)

When this bit is enabled, CSI DMA will switch the base address according to BASEADDR_SWITCH_SEL rather than automatically by DMA completed

pub const fn baseaddr_switch_sel(&self) -> BaseaddrSwitchSel

CSI 2 base addresses switching method. When using this bit, BASEADDR_SWITCH_EN is 1.

pub const fn set_baseaddr_switch_sel(&mut self, val: BaseaddrSwitchSel)

CSI 2 base addresses switching method. When using this bit, BASEADDR_SWITCH_EN is 1.

pub const fn field0_done_ie(&self) -> Field0DoneIe

In interlace mode, field 0 means interrupt enabled.

pub const fn set_field0_done_ie(&mut self, val: Field0DoneIe)

In interlace mode, field 0 means interrupt enabled.

pub const fn dma_field1_done_ie(&self) -> DmaField1DoneIe

When in interlace mode, field 1 done interrupt enable.

pub const fn set_dma_field1_done_ie(&mut self, val: DmaField1DoneIe)

When in interlace mode, field 1 done interrupt enable.

pub const fn last_dma_req_sel(&self) -> LastDmaReqSel

Choosing the last DMA request condition

pub const fn set_last_dma_req_sel(&mut self, val: LastDmaReqSel)

Choosing the last DMA request condition

pub const fn baseaddr_change_error_ie(&self) -> BaseaddrChangeErrorIe

Base address change error interrupt enable signal.

pub const fn set_baseaddr_change_error_ie(&mut self, val: BaseaddrChangeErrorIe)

Base address change error interrupt enable signal.

pub const fn rgb888a_format_sel(&self) -> Rgb888aFormatSel

Output is 32-bit format.

pub const fn set_rgb888a_format_sel(&mut self, val: Rgb888aFormatSel)

Output is 32-bit format.

pub const fn ahb_hprot(&self) -> u8

Hprot value in AHB bus protocol.

pub const fn set_ahb_hprot(&mut self, val: u8)

Hprot value in AHB bus protocol.

pub const fn mask_option(&self) -> MaskOption

These bits used to choose the method to mask the CSI input.

pub const fn set_mask_option(&mut self, val: MaskOption)

These bits used to choose the method to mask the CSI input.

pub const fn csi_enable(&self) -> bool

CSI global enable signal

pub const fn set_csi_enable(&mut self, val: bool)

CSI global enable signal