nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Cr2

Struct Cr2 

#[repr(transparent)]
pub struct Cr2(pub u32);
CSI Control Register 2

Tuple Fields

0: u32

Implementations

Source

impl Cr2

pub const fn hsc(&self) -> Hsc

Horizontal Skip Count

pub const fn set_hsc(&mut self, val: Hsc)

Horizontal Skip Count

pub const fn vsc(&self) -> Vsc

Vertical Skip Count. Contains the number of rows to skip. SCE must be 1, otherwise VSC is ignored.

pub const fn set_vsc(&mut self, val: Vsc)

Vertical Skip Count. Contains the number of rows to skip. SCE must be 1, otherwise VSC is ignored.

pub const fn lvrm(&self) -> Lvrm

Live View Resolution Mode. Selects the grid size used for live view resolution.

pub const fn set_lvrm(&mut self, val: Lvrm)

Live View Resolution Mode. Selects the grid size used for live view resolution.

pub const fn bts(&self) -> Bts

Bayer Tile Start. Controls the Bayer pattern starting point.

pub const fn set_bts(&mut self, val: Bts)

Bayer Tile Start. Controls the Bayer pattern starting point.

pub const fn sce(&self) -> Sce

Skip Count Enable

pub const fn set_sce(&mut self, val: Sce)

Skip Count Enable

pub const fn afs(&self) -> Afs

Auto Focus Spread. Selects which green pixels are used for auto-focus.

pub const fn set_afs(&mut self, val: Afs)

Auto Focus Spread. Selects which green pixels are used for auto-focus.

pub const fn drm(&self) -> Drm

Double Resolution Mode. Controls size of statistics grid.

pub const fn set_drm(&mut self, val: Drm)

Double Resolution Mode. Controls size of statistics grid.

pub const fn dma_burst_type_sff(&self) -> DmaBurstTypeSff

Burst Type of DMA Transfer from STATFIFO. Selects the burst type of DMA transfer from STATFIFO.

pub const fn set_dma_burst_type_sff(&mut self, val: DmaBurstTypeSff)

Burst Type of DMA Transfer from STATFIFO. Selects the burst type of DMA transfer from STATFIFO.

pub const fn dma_burst_type_rff(&self) -> DmaBurstTypeRff

Burst Type of DMA Transfer from RxFIFO. Selects the burst type of DMA transfer from RxFIFO.

pub const fn set_dma_burst_type_rff(&mut self, val: DmaBurstTypeRff)

Burst Type of DMA Transfer from RxFIFO. Selects the burst type of DMA transfer from RxFIFO.