#[repr(transparent)]pub struct Sr(pub u32);Expand description
CSI Status Register
Tuple Fields
0: u32Implementations
Sourceimpl Sr
impl Sr
Sourcepub const fn set_ecc_int(&mut self, val: EccInt)
pub const fn set_ecc_int(&mut self, val: EccInt)
BT
Sourcepub const fn hresp_err_int(&self) -> HrespErrInt
pub const fn hresp_err_int(&self) -> HrespErrInt
Hresponse Error Interrupt Status
Sourcepub const fn set_hresp_err_int(&mut self, val: HrespErrInt)
pub const fn set_hresp_err_int(&mut self, val: HrespErrInt)
Hresponse Error Interrupt Status
Sourcepub const fn set_cof_int(&mut self, val: CofInt)
pub const fn set_cof_int(&mut self, val: CofInt)
Change Of Field Interrupt Status
Sourcepub const fn set_f1_int(&mut self, val: F1Int)
pub const fn set_f1_int(&mut self, val: F1Int)
BT
Sourcepub const fn set_f2_int(&mut self, val: F2Int)
pub const fn set_f2_int(&mut self, val: F2Int)
BT
Sourcepub const fn sof_int(&self) -> SofInt
pub const fn sof_int(&self) -> SofInt
Start of Frame Interrupt Status. Indicates when SOF is detected. (Cleared by writing 1)
Sourcepub const fn set_sof_int(&mut self, val: SofInt)
pub const fn set_sof_int(&mut self, val: SofInt)
Start of Frame Interrupt Status. Indicates when SOF is detected. (Cleared by writing 1)
Sourcepub const fn eof_int(&self) -> EofInt
pub const fn eof_int(&self) -> EofInt
End of Frame (EOF) Interrupt Status. Indicates when EOF is detected. (Cleared by writing 1)
Sourcepub const fn set_eof_int(&mut self, val: EofInt)
pub const fn set_eof_int(&mut self, val: EofInt)
End of Frame (EOF) Interrupt Status. Indicates when EOF is detected. (Cleared by writing 1)
Sourcepub const fn set_rx_ff_int(&mut self, val: RxFfInt)
pub const fn set_rx_ff_int(&mut self, val: RxFfInt)
RXFIFO Full Interrupt Status
Sourcepub const fn dma_tsf_done_fb1(&self) -> DmaTsfDoneFb1
pub const fn dma_tsf_done_fb1(&self) -> DmaTsfDoneFb1
DMA Transfer Done in Frame Buffer1
Sourcepub const fn set_dma_tsf_done_fb1(&mut self, val: DmaTsfDoneFb1)
pub const fn set_dma_tsf_done_fb1(&mut self, val: DmaTsfDoneFb1)
DMA Transfer Done in Frame Buffer1
Sourcepub const fn dma_tsf_done_fb2(&self) -> DmaTsfDoneFb2
pub const fn dma_tsf_done_fb2(&self) -> DmaTsfDoneFb2
DMA Transfer Done in Frame Buffer2
Sourcepub const fn set_dma_tsf_done_fb2(&mut self, val: DmaTsfDoneFb2)
pub const fn set_dma_tsf_done_fb2(&mut self, val: DmaTsfDoneFb2)
DMA Transfer Done in Frame Buffer2
Sourcepub const fn statff_int(&self) -> StatffInt
pub const fn statff_int(&self) -> StatffInt
STATFIFO Full Interrupt Status
Sourcepub const fn set_statff_int(&mut self, val: StatffInt)
pub const fn set_statff_int(&mut self, val: StatffInt)
STATFIFO Full Interrupt Status
Sourcepub const fn dma_tsf_done_sff(&self) -> DmaTsfDoneSff
pub const fn dma_tsf_done_sff(&self) -> DmaTsfDoneSff
DMA Transfer Done from StatFIFO
Sourcepub const fn set_dma_tsf_done_sff(&mut self, val: DmaTsfDoneSff)
pub const fn set_dma_tsf_done_sff(&mut self, val: DmaTsfDoneSff)
DMA Transfer Done from StatFIFO
Sourcepub const fn set_rf_or_int(&mut self, val: RfOrInt)
pub const fn set_rf_or_int(&mut self, val: RfOrInt)
RxFIFO Overrun Interrupt Status
Sourcepub const fn set_sf_or_int(&mut self, val: SfOrInt)
pub const fn set_sf_or_int(&mut self, val: SfOrInt)
STATFIFO Overrun Interrupt Status
Sourcepub const fn dma_field1_done(&self) -> bool
pub const fn dma_field1_done(&self) -> bool
When DMA field 1 is complete, this bit will be set to 1(clear by writing 1).
Sourcepub const fn set_dma_field1_done(&mut self, val: bool)
pub const fn set_dma_field1_done(&mut self, val: bool)
When DMA field 1 is complete, this bit will be set to 1(clear by writing 1).
Sourcepub const fn dma_field0_done(&self) -> bool
pub const fn dma_field0_done(&self) -> bool
When DMA field 0 is complete, this bit will be set to 1(clear by writing 1).
Sourcepub const fn set_dma_field0_done(&mut self, val: bool)
pub const fn set_dma_field0_done(&mut self, val: bool)
When DMA field 0 is complete, this bit will be set to 1(clear by writing 1).
Sourcepub const fn baseaddr_chhange_error(&self) -> bool
pub const fn baseaddr_chhange_error(&self) -> bool
When using base address switching enable, this bit will be 1 when switching occur before DMA complete
Sourcepub const fn set_baseaddr_chhange_error(&mut self, val: bool)
pub const fn set_baseaddr_chhange_error(&mut self, val: bool)
When using base address switching enable, this bit will be 1 when switching occur before DMA complete