#[repr(transparent)]pub struct Cr18(pub u32);Expand description
CSI Control Register 18
Tuple Fields
0: u32Implementations
Sourceimpl Cr18
impl Cr18
Sourcepub const fn deinterlace_en(&self) -> DeinterlaceEn
pub const fn deinterlace_en(&self) -> DeinterlaceEn
This bit is used to select the output method When input is standard BT.656 video.
Sourcepub const fn set_deinterlace_en(&mut self, val: DeinterlaceEn)
pub const fn set_deinterlace_en(&mut self, val: DeinterlaceEn)
This bit is used to select the output method When input is standard BT.656 video.
Sourcepub const fn parallel24_en(&self) -> Parallel24En
pub const fn parallel24_en(&self) -> Parallel24En
Enable bit for Parallel RGB888/YUV444 24bit input
Sourcepub const fn set_parallel24_en(&mut self, val: Parallel24En)
pub const fn set_parallel24_en(&mut self, val: Parallel24En)
Enable bit for Parallel RGB888/YUV444 24bit input
Sourcepub const fn baseaddr_switch_en(&self) -> bool
pub const fn baseaddr_switch_en(&self) -> bool
When this bit is enabled, CSI DMA will switch the base address according to BASEADDR_SWITCH_SEL rather than automatically by DMA completed
Sourcepub const fn set_baseaddr_switch_en(&mut self, val: bool)
pub const fn set_baseaddr_switch_en(&mut self, val: bool)
When this bit is enabled, CSI DMA will switch the base address according to BASEADDR_SWITCH_SEL rather than automatically by DMA completed
Sourcepub const fn baseaddr_switch_sel(&self) -> BaseaddrSwitchSel
pub const fn baseaddr_switch_sel(&self) -> BaseaddrSwitchSel
CSI 2 base addresses switching method. When using this bit, BASEADDR_SWITCH_EN is 1.
Sourcepub const fn set_baseaddr_switch_sel(&mut self, val: BaseaddrSwitchSel)
pub const fn set_baseaddr_switch_sel(&mut self, val: BaseaddrSwitchSel)
CSI 2 base addresses switching method. When using this bit, BASEADDR_SWITCH_EN is 1.
Sourcepub const fn field0_done_ie(&self) -> Field0DoneIe
pub const fn field0_done_ie(&self) -> Field0DoneIe
In interlace mode, field 0 means interrupt enabled.
Sourcepub const fn set_field0_done_ie(&mut self, val: Field0DoneIe)
pub const fn set_field0_done_ie(&mut self, val: Field0DoneIe)
In interlace mode, field 0 means interrupt enabled.
Sourcepub const fn dma_field1_done_ie(&self) -> DmaField1DoneIe
pub const fn dma_field1_done_ie(&self) -> DmaField1DoneIe
When in interlace mode, field 1 done interrupt enable.
Sourcepub const fn set_dma_field1_done_ie(&mut self, val: DmaField1DoneIe)
pub const fn set_dma_field1_done_ie(&mut self, val: DmaField1DoneIe)
When in interlace mode, field 1 done interrupt enable.
Sourcepub const fn last_dma_req_sel(&self) -> LastDmaReqSel
pub const fn last_dma_req_sel(&self) -> LastDmaReqSel
Choosing the last DMA request condition
Sourcepub const fn set_last_dma_req_sel(&mut self, val: LastDmaReqSel)
pub const fn set_last_dma_req_sel(&mut self, val: LastDmaReqSel)
Choosing the last DMA request condition
Sourcepub const fn baseaddr_change_error_ie(&self) -> BaseaddrChangeErrorIe
pub const fn baseaddr_change_error_ie(&self) -> BaseaddrChangeErrorIe
Base address change error interrupt enable signal.
Sourcepub const fn set_baseaddr_change_error_ie(&mut self, val: BaseaddrChangeErrorIe)
pub const fn set_baseaddr_change_error_ie(&mut self, val: BaseaddrChangeErrorIe)
Base address change error interrupt enable signal.
Sourcepub const fn rgb888a_format_sel(&self) -> Rgb888aFormatSel
pub const fn rgb888a_format_sel(&self) -> Rgb888aFormatSel
Output is 32-bit format.
Sourcepub const fn set_rgb888a_format_sel(&mut self, val: Rgb888aFormatSel)
pub const fn set_rgb888a_format_sel(&mut self, val: Rgb888aFormatSel)
Output is 32-bit format.
Sourcepub const fn set_ahb_hprot(&mut self, val: u8)
pub const fn set_ahb_hprot(&mut self, val: u8)
Hprot value in AHB bus protocol.
Sourcepub const fn mask_option(&self) -> MaskOption
pub const fn mask_option(&self) -> MaskOption
These bits used to choose the method to mask the CSI input.
Sourcepub const fn set_mask_option(&mut self, val: MaskOption)
pub const fn set_mask_option(&mut self, val: MaskOption)
These bits used to choose the method to mask the CSI input.
Sourcepub const fn csi_enable(&self) -> bool
pub const fn csi_enable(&self) -> bool
CSI global enable signal
Sourcepub const fn set_csi_enable(&mut self, val: bool)
pub const fn set_csi_enable(&mut self, val: bool)
CSI global enable signal