#[repr(transparent)]pub struct Cr2(pub u32);Expand description
CSI Control Register 2
Tuple Fields
0: u32Implementations
Sourceimpl Cr2
impl Cr2
Sourcepub const fn vsc(&self) -> Vsc
pub const fn vsc(&self) -> Vsc
Vertical Skip Count. Contains the number of rows to skip. SCE must be 1, otherwise VSC is ignored.
Sourcepub const fn set_vsc(&mut self, val: Vsc)
pub const fn set_vsc(&mut self, val: Vsc)
Vertical Skip Count. Contains the number of rows to skip. SCE must be 1, otherwise VSC is ignored.
Sourcepub const fn lvrm(&self) -> Lvrm
pub const fn lvrm(&self) -> Lvrm
Live View Resolution Mode. Selects the grid size used for live view resolution.
Sourcepub const fn set_lvrm(&mut self, val: Lvrm)
pub const fn set_lvrm(&mut self, val: Lvrm)
Live View Resolution Mode. Selects the grid size used for live view resolution.
Sourcepub const fn set_bts(&mut self, val: Bts)
pub const fn set_bts(&mut self, val: Bts)
Bayer Tile Start. Controls the Bayer pattern starting point.
Sourcepub const fn afs(&self) -> Afs
pub const fn afs(&self) -> Afs
Auto Focus Spread. Selects which green pixels are used for auto-focus.
Sourcepub const fn set_afs(&mut self, val: Afs)
pub const fn set_afs(&mut self, val: Afs)
Auto Focus Spread. Selects which green pixels are used for auto-focus.
Sourcepub const fn set_drm(&mut self, val: Drm)
pub const fn set_drm(&mut self, val: Drm)
Double Resolution Mode. Controls size of statistics grid.
Sourcepub const fn dma_burst_type_sff(&self) -> DmaBurstTypeSff
pub const fn dma_burst_type_sff(&self) -> DmaBurstTypeSff
Burst Type of DMA Transfer from STATFIFO. Selects the burst type of DMA transfer from STATFIFO.
Sourcepub const fn set_dma_burst_type_sff(&mut self, val: DmaBurstTypeSff)
pub const fn set_dma_burst_type_sff(&mut self, val: DmaBurstTypeSff)
Burst Type of DMA Transfer from STATFIFO. Selects the burst type of DMA transfer from STATFIFO.
Sourcepub const fn dma_burst_type_rff(&self) -> DmaBurstTypeRff
pub const fn dma_burst_type_rff(&self) -> DmaBurstTypeRff
Burst Type of DMA Transfer from RxFIFO. Selects the burst type of DMA transfer from RxFIFO.
Sourcepub const fn set_dma_burst_type_rff(&mut self, val: DmaBurstTypeRff)
pub const fn set_dma_burst_type_rff(&mut self, val: DmaBurstTypeRff)
Burst Type of DMA Transfer from RxFIFO. Selects the burst type of DMA transfer from RxFIFO.